==> flink-1.18.1-src.tgz: flink-1.18.1/flink-runtime/src/test/java/org/apache/flink/runtime/scheduler/benchmark/failover/RegionToRestartInStreamingJobBenchmarkTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License
 */

package org.apache.flink.runtime.scheduler.benchmark.failover;

import org.apache.flink.runtime.executiongraph.failover.flip1.RestartPipelinedRegionFailoverStrategy;
import org.apache.flink.runtime.scheduler.benchmark.JobConfiguration;

import org.junit.jupiter.api.Test;

/**
 * The benchmark of calculating region to restart when failover occurs in a STREAMING job. The
 * related method is {@link RestartPipelinedRegionFailoverStrategy#getTasksNeedingRestart}.
 */
class RegionToRestartInStreamingJobBenchmarkTest {

    @Test
    void calculateRegionToRestart() throws Exception {
        RegionToRestartInStreamingJobBenchmark benchmark =
                new RegionToRestartInStreamingJobBenchmark();
        benchmark.setup(JobConfiguration.STREAMING_TEST);
        benchmark.calculateRegionToRestart();
        benchmark.teardown();
    }
}

==> flink-1.19.3-src.tgz: flink-1.19.3/flink-runtime/src/test/java/org/apache/flink/runtime/scheduler/benchmark/failover/RegionToRestartInStreamingJobBenchmarkTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License
 */

package org.apache.flink.runtime.scheduler.benchmark.failover;

import org.apache.flink.runtime.executiongraph.failover.RestartPipelinedRegionFailoverStrategy;
import org.apache.flink.runtime.scheduler.benchmark.JobConfiguration;

import org.junit.jupiter.api.Test;

/**
 * The benchmark of calculating region to restart when failover occurs in a STREAMING job. The
 * related method is {@link RestartPipelinedRegionFailoverStrategy#getTasksNeedingRestart}.
 */
class RegionToRestartInStreamingJobBenchmarkTest {

    @Test
    void calculateRegionToRestart() throws Exception {
        RegionToRestartInStreamingJobBenchmark benchmark =
                new RegionToRestartInStreamingJobBenchmark();
        benchmark.setup(JobConfiguration.STREAMING_TEST);
        benchmark.calculateRegionToRestart();
        benchmark.teardown();
    }
}
